# Business Context Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#description)
  * [Business Context Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#business-context-fact-sheet-subtypes)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#guidelines-and-best-practices)
  * [Example 1: Product Architecture](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#example-1:-product-architecture)
  * [Example 2: How to Model Business Architecture with Value Streams and Processes (Manufacturing Company)](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#example-2:-how-to-model-business-architecture-with-value-streams-and-processes-\(manufacturing-company\))
  * [Example 3: How to Model Business Architecture with Customer Journey and Business Products (Digital Bank)](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#example-3:-how-to-model-business-architecture-with-customer-journey-and-business-products-\(digital-bank\))
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines#antipatterns)


View all
Learn how to model business contexts. This includes best practices and applicable use cases, and common antipatterns.
